@@ -1,11 +1,10 @@
 package Bot::Training;
-BEGIN {
-  $Bot::Training::VERSION = '0.04';
-}
-
+our $AUTHORITY = 'cpan:AVAR';
+$Bot::Training::VERSION = '0.05';
 use 5.010;
 use autodie qw(open close);
-use Any::Moose;
+use Class::Load;
+use Moose;
 use Module::Pluggable (
     search_path => [ 'Bot::Training' ],
     except      => [ 'Bot::Training::Plugin' ],
@@ -13,7 +12,7 @@ use Module::Pluggable (
 use List::Util qw< first >;
 use namespace::clean -except => [ qw< meta plugins > ];
 
-with any_moose('X::Getopt::Dashes');
+with 'MooseX::Getopt::Dashes';
 
 has help => (
     traits        => [ qw/ Getopt / ],
@@ -71,13 +70,7 @@ sub _new_class {
         }
     }
 
-    if (Any::Moose::moose_is_preferred()) {
-        require Class::MOP;
-        eval { Class::MOP::load_class($pkg) };
-    } else {
-        eval qq[require $pkg];
-    }
-    die $@ if $@;
+    Class::Load::load_class($pkg);
 
     return $pkg->new;
 }
